package
Version:
v0.0.0-...-5320b4e
Opens a new window with list of versions in this module.
Published: May 4, 2024
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Config struct {
Port int `mapstructure:"port"`
BaseUrl string `mapstructure:"base_url"`
AllowedPaths []string `mapstructure:"allowed_paths"`
}
func LoadConfig() (config *Config)
Source Files
¶
Click to show internal directories.
Click to hide internal directories.